@@ -1,4 +1,4 @@
-# Copyright (C) 2012 Science and Technology Facilities Council.
+# Copyright (C) 2012-13 Science and Technology Facilities Council.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -77,19 +77,7 @@ class CrabMonitor(CrabMinutely):
         for job in jobs:
             id_ = job['id']
             try:
-                self._initialize_job(id_)
-
-                # Allow a margin of events over HISTORY_COUNT to allow
-                # for start events and alarms.
-                events = self.store.get_job_events(id_, 4 * HISTORY_COUNT)
-
-                # Events are returned newest-first but we need to work
-                # through them in order.
-                for event in reversed(events):
-                    self._update_max_id_values(event)
-                    self._process_event(id_, event)
-
-                self._compute_reliability(id_)
+                self._initialize_job(id_, load_events=True)
 
             except JobDeleted:
                 print('Warning: job', id_, 'has vanished')
@@ -184,12 +172,8 @@ class CrabMonitor(CrabMinutely):
                 # need to do this?
                 self._configure_job(id_)
             else:
-                # No need to check event history: if there were any
-                # events, we would have added the job when they
-                # occurred (unless a job was just un-deleted or the
-                # an event happend during the schedule check.
                 try:
-                    self._initialize_job(id_)
+                    self._initialize_job(id_, load_events=True)
                 except JobDeleted:
                     print('Warning: job', id_, 'has vanished')
 
@@ -197,7 +181,7 @@ class CrabMonitor(CrabMinutely):
         for id_ in currentjobs:
             self._remove_job(id_)
 
-    def _initialize_job(self, id_):
+    def _initialize_job(self, id_, load_events=False):
         """Fetches information about the specified job and records it
         in the instance data structures.  Includes a call to _schedule_job."""
 
@@ -211,6 +195,19 @@ class CrabMonitor(CrabMinutely):
         self._schedule_job(id_, jobinfo)
         self._configure_job(id_)
 
+        if load_events:
+            # Allow a margin of events over HISTORY_COUNT to allow
+            # for start events and alarms.
+            events = self.store.get_job_events(id_, 4 * HISTORY_COUNT)
+
+            # Events are returned newest-first but we need to work
+            # through them in order.
+            for event in reversed(events):
+                self._update_max_id_values(event)
+                self._process_event(id_, event)
+
+            self._compute_reliability(id_)
+
     def _schedule_job(self, id_, jobinfo=None):
         """Sets or updates job scheduling information.
 
@@ -299,7 +296,10 @@ class CrabMonitor(CrabMinutely):
 
             # Avoid overwriting a status with a less important one.
 
-            if CrabStatus.is_trivial(status):
+            if status == CrabStatus.CLEARED:
+                self.status[id_]['status'] = status
+
+            elif CrabStatus.is_trivial(status):
                 if prevstatus is None or CrabStatus.is_ok(prevstatus):
                     self.status[id_]['status'] = status
 
@@ -318,14 +318,19 @@ class CrabMonitor(CrabMinutely):
                     del history[0]
                 history.append(status)
 
-        if event['type'] == CrabEvent.START:
+        # Handle ALREADYRUNNING as a 'start' type event, so that
+        # the MISSED alarm is not raised and the timeout period
+        # is extended.
+
+        if (event['type'] == CrabEvent.START
+                or event['status'] == CrabStatus.ALREADYRUNNING):
             self.status[id_]['running'] = True
             self.last_start[id_] = datetime_
             self.timeout[id_] = datetime_ + self.config[id_]['timeout']
             if id_ in self.miss_timeout:
                 del self.miss_timeout[id_]
 
-        if (event['type'] == CrabEvent.FINISH
+        elif (event['type'] == CrabEvent.FINISH
                 or event['status'] == CrabStatus.TIMEOUT):
             self.status[id_]['running'] = False
             if id_ in self.timeout:
@@ -351,14 +356,24 @@ class CrabMonitor(CrabMinutely):
         except CrabError as err:
             print('Could not record alarm: ', str(err))
 
-    def get_job_status(self):
+    def get_job_status(self, id_=None):
         """Fetches the status of all jobs as a dict.
 
         For efficiency this returns a reference to our job status dict.
-        Callers should not modify it."""
+        Callers should not modify it.  If a job ID is specified, the
+        status entry for that job is returned, or a dummy entry if it is not
+        in the status dict."""
 
         self.status_ready.wait()
-        return self.status
+
+        if id_ is None:
+            return self.status
+
+        else:
+            if id_ in self.status:
+                return self.status[id_]
+            else:
+                return {'status': None, 'running': False}
 
     def wait_for_event_since(self, startid, alarmid, finishid, timeout=120):
         """Function which waits for new events.
