@@ -17,7 +17,8 @@ from __future__ import print_function
 
 import re
 
-from crab.util.string import remove_quotes, quote_multiword, split_quoted_word
+from crab.util.string import remove_quotes, quote_multiword, \
+                             split_crab_vars, true_string
 
 class CrabStore:
     def get_jobs(self, host=None, user=None, include_deleted=False):
@@ -93,10 +94,11 @@ class CrabStore:
         variable = re.compile('^\s*(\w+)\s*=\s*(.*)$')
         cronrule = re.compile('^\s*(@\w+|\S+\s+\S+\s+\S+\s+\S+\s+\S+)\s+(.*)$')
 
-        crabid = None
         idset = set()
         idsaved = set()
         warning = []
+        env = {}
+
         for job in self.get_jobs(host, user):
             idset.add(job['id'])
 
@@ -112,27 +114,26 @@ class CrabStore:
                 m = variable.search(job)
                 if m is not None:
                     (var, value) = m.groups()
-                    if var == 'CRABID':
-                        crabid = remove_quotes(value.rstrip())
                     if var == 'CRON_TZ':
                         timezone = remove_quotes(value.rstrip())
+                    elif var.startswith('CRAB'):
+                        env[var] = remove_quotes(value.rstrip())
                     continue
 
                 m = cronrule.search(job)
                 if m is not None:
                     (time, command) = m.groups()
+                    (command, jobvars) = split_crab_vars(command)
+                    vars = env.copy()
+                    vars.update(jobvars)
 
-                    if command.startswith('CRABIGNORE='):
-                        (ignore, command) = split_quoted_word(command[11:])
-                        if ignore.lower() not in ['0', 'no', 'false', 'off']:
+                    if 'CRABIGNORE' in vars:
+                        if true_string(vars['CRABIGNORE']):
                             continue
 
-                    if command.startswith('CRABID='):
-                        (crabid, command) = split_quoted_word(command[7:])
-
                     command = command.rstrip()
 
-                    id_ = self._check_job(host, user, crabid,
+                    id_ = self._check_job(host, user, vars.get('CRABID'),
                                           command, time, timezone)
 
                     if id_ in idsaved:
@@ -142,7 +143,7 @@ class CrabStore:
                         idsaved.add(id_)
 
                     idset.discard(id_)
-                    crabid = None
+
                     continue
 
                 warning.append('Did not recognise line: ' + job)
