@@ -78,16 +78,17 @@ class CrabWebQuery:
 class CrabWeb:
     """CherryPy handler for the HTML part of the crab web interface."""
 
-    def __init__(self, config, store, monitor, service):
+    def __init__(self, store, monitor, crab_home, service, options):
         """Constructor for CrabWeb class.
 
-        Stores a reference to the given storage backend, and extracts
+        Stores a reference to the given storage backend, and
         the home directory from the config dict.  Prepares the template
         engine and instantiates a CrabWebQuery object which CherryPy
         can find as 'query'."""
         self.store = store
-        home = config['crab']['home']
-        self.templ = TemplateLookup(directories=[home + '/templ'])
+        self.monitor = monitor
+        self.options = options
+        self.templ = TemplateLookup(directories=[crab_home + '/templ'])
         self.query = CrabWebQuery(store, monitor, service)
 
     @cherrypy.expose
@@ -107,6 +108,7 @@ class CrabWeb:
             barerows=None, unfiltered=None, limit=None, enddate=None,
 
             submit_config=None, submit_relink=None,
+            submit_confirm=None, submit_cancel=None,
             orphan=None, graceperiod=None, timeout=None,
 
             submit_notify=None, **kwargs):
@@ -182,9 +184,31 @@ class CrabWeb:
 
             return self._write_template('job.html',
                        {'id': id_, 'info': info, 'config': config,
+                        'status': self.monitor.get_job_status(id_),
                         'notification': notification, 'events': events,
                         'lastdatetime': lastdatetime})
 
+        elif command == 'clear':
+            if submit_confirm:
+                self.store.log_alarm(id_, CrabStatus.CLEARED)
+
+                # Wait for the monitor to process new events so that
+                # that the job is in an 'OK' state before we reload the page.
+                with self.monitor.new_event:
+                    self.monitor.new_event.wait(10)
+
+                raise HTTPRedirect("/job/" + str(id_))
+
+            elif submit_cancel:
+                raise HTTPRedirect("/job/" + str(id_))
+
+            else:
+                return self._write_template('confirm.html',
+                       {'id': id_, 'info': info,
+                        'title': 'clear status',
+                        'description': 'Reset the job status?',
+                        'target': '/job/' + str(id_) + '/clear'})
+
         elif command == 'output':
             finishid_next = None
             finishid_prev = None
@@ -222,16 +246,12 @@ class CrabWeb:
                 if finishes:
                     finishid_next = finishes[0]['finishid']
 
-            pair = self.store.get_job_output(finishid,
+            (stdout, stderr) = self.store.get_job_output(finishid,
                     info['host'], info['user'], id_, info['crabid'])
 
-            if pair is None:
-                raise HTTPError(404, 'No output found for the given job run.')
-
             filter = CrabEventFilter(self.store, info['timezone'])
             finish['datetime'] = filter.in_timezone(finish['datetime'])
 
-            (stdout, stderr) = pair
             return self._write_template('joboutput.html',
                        {'id': id_, 'info': info, 'finish': finish,
                         'stdout': stdout, 'stderr': stderr,
@@ -339,7 +359,7 @@ class CrabWeb:
                              'notifications': notifications})
 
         else:
-            raise HTTPError(404)
+            raise HTTPError(404, 'Unknown job command')
 
     @cherrypy.expose
     def user(self, user):
@@ -449,7 +469,7 @@ class CrabWeb:
 
         try:
             template = self.templ.get_template(name)
-            return template.render(**dict)
+            return template.render(options=self.options, **dict)
         except:
             return exceptions.html_error_template().render()
 
